@@ -83,9 +83,11 @@ class ItemInfo:
 
     name: str = "item"
     price: Money = field(default_factory=Money)
-    category: str = ""
+    category: str = "none"
+    subcategory: str = "none"
     level: int = 0
     rarity: str = "common"
+    bulk: typing.Union[int, str] = 0
 
 
 def get_higher_rarity(rar1: str, rar2: str) -> str:
@@ -152,7 +154,7 @@ def parse_database(
     if re.match(r"\d+([,\.]\d*)?\s*(cp|sp|gp)", item_name) is not None:
         currency_value = get_price(item_name, amount)
         currency_value.origin = "currency"
-        return ItemInfo(item_name, currency_value, "currency")
+        return ItemInfo(item_name, currency_value, "currency", "none")
 
     # Check if the first one or two words denote a precious material
     item_name, material, grade = get_material_grade(item_name.split(), materials)
@@ -161,7 +163,11 @@ def parse_database(
     # They're technically "worn items", not "weapons", but using the right category
     # breaks potency rune price calculation
     if item_name == "handwraps of mighty blows":
-        return ItemInfo("handwraps of mighty blows", category="weapons")
+        return ItemInfo(
+            "handwraps of mighty blows",
+            category="weapons",
+            subcategory="other worn items",
+        )
 
     # If category is restricted, check only items from that category
     if restrict_cat:
@@ -178,18 +184,26 @@ def parse_database(
             suggestion = "".join(
                 get_close_matches(item_name.strip(), df["name"].tolist(), 1, 0)
             )
-            print(f'WARNING: Ignoring item "{item_name}". Did you mean "{suggestion}"?')
+
+            if item_name != suggestion:
+                print(
+                    f'WARNING: Ignoring item "{item_name}". Did you mean "{suggestion}"?'
+                )
 
         return ItemInfo(item_name, category="error")
 
     # Fix shield name including "steel" or "wooden" even if it's made of a precious material
-    if "shield" in item_name and not "tower" in item_name and material:
+    if material and "shield" in item_name and not "tower" in item_name:
         item_name = "shield"
 
     # Get item stats
     item_category = item_row["category"].item() if not restrict_cat else restrict_cat
+    item_subcategory = item_row["subcategory"].item()
     item_level = item_row["level"].item()
     item_rarity = item_row["rarity"].item()
+    item_bulk = item_row["bulk"].item()
+    if item_bulk.isdigit():
+        item_bulk = int(item_bulk)
 
     # Get item price
     if not material:
@@ -220,7 +234,15 @@ def parse_database(
         material_rarity = df[df["name"] == material_name]["rarity"].item()
         item_rarity = get_higher_rarity(material_rarity, item_rarity)
 
-    return ItemInfo(item_name, item_price, item_category, item_level, item_rarity)
+    return ItemInfo(
+        item_name,
+        item_price,
+        item_category,
+        item_subcategory,
+        item_level,
+        item_rarity,
+        item_bulk,
+    )
 
 
 def get_potency_rune_stats(
@@ -333,14 +355,7 @@ def rune_calculator(
 
         # Find the rune in the list of runes (if present)
         if rune not in materials:
-            rune_info = parse_database(
-                rune,
-                amount,
-                df=df,
-                materials=materials,
-                restrict_cat="runes",
-                quiet=True,
-            )
+            rune_info = parse_database(rune, amount, restrict_cat="runes")
         else:
             rune_info = ItemInfo(rune, category="error")
             material_flag = True
@@ -385,7 +400,13 @@ def rune_calculator(
     )
     running_sum += add_to_sum
     return ItemInfo(
-        item_name, running_sum, rune_info.category, highest_level, highest_rarity
+        item_name,
+        running_sum,
+        rune_info.category,
+        rune_info.subcategory,
+        highest_level,
+        highest_rarity,
+        rune_info.bulk,
     )
 
 
@@ -397,8 +418,11 @@ def get_price(price_str: str, amount: int = 1) -> Money:
     """
 
     # Fetch price and coin type through regex
-    price_match = re.search(r"\d*(,\d*)?", price_str)
-    type_match = re.search(r"cp|sp|gp", price_str)
+    try:
+        price_match = re.search(r"\d*(,\d*)?", price_str)
+        type_match = re.search(r"cp|sp|gp", price_str)
+    except TypeError:
+        return Money()
 
     # Check which kind of coin it is (if any)
     if type_match is not None and price_match is not None:
@@ -418,7 +442,7 @@ def get_price(price_str: str, amount: int = 1) -> Money:
         return Money()
 
 
-def console_entry_point(input_file, level, currency, noconversion):
+def console_entry_point(input_file, level, currency, detailed, noconversion):
     """Primary entry point for the script."""
 
     # User-defined loot
@@ -433,7 +457,8 @@ def console_entry_point(input_file, level, currency, noconversion):
     money = {"item": Money(origin="item"), "currency": Money(origin="currency")}
 
     levels: dict[str, int] = {}
-    categories: dict[typing.Union[str, None], int] = {}
+    categories: dict[str, int] = {}
+    subcategories: dict[str, int] = {}
     rarities: dict[str, int] = {}
 
     # Get the price for each item
@@ -457,6 +482,11 @@ def console_entry_point(input_file, level, currency, noconversion):
         except KeyError:
             categories[curr_item.category] = amount
 
+        try:
+            subcategories[curr_item.subcategory] += amount
+        except KeyError:
+            subcategories[curr_item.subcategory] = amount
+
         try:
             rarities[curr_item.rarity] += amount
         except KeyError:
@@ -518,52 +548,55 @@ def console_entry_point(input_file, level, currency, noconversion):
 
     money["total"] = get_total(money.values())
 
-    print("Total value", end="")
+    print("\nTotal value", end="")
     if not noconversion:
         print(" (converted in gp)", end="")
     print(":")
     print(
         textwrap.dedent(
             f"""\
-            {money["total"].cp} cp
-            {money["total"].sp} sp
-            {money["total"].gp} gp
+          - {money["total"].cp} cp
+          - {money["total"].sp} sp
+          - {money["total"].gp} gp
 
         Of which:
-            Items: {money["item"].gp} gp
-            Currency: {money["currency"].gp} gp
+          - Items: {money["item"].gp} gp
+          - Currency: {money["currency"].gp} gp\
         """
         )
     )
 
     if level:
-        print("Difference:")
+        print("\nDifference:")
         if total_value - money["total"].gp < 0:
             print(
-                f"    {abs(total_value - money['total'].gp)} gp too much (Expected {total_value} gp)"
+                f"  - {abs(total_value - money['total'].gp)} gp too much (Expected {total_value} gp)"
             )
         elif total_value - money["total"].gp > 0:
             print(
-                f"    {abs(total_value - money['total'].gp)} gp too little (Expected {total_value} gp)"
+                f"  - {abs(total_value - money['total'].gp)} gp too little (Expected {total_value} gp)"
             )
         else:
-            print(f"    None (Expected {total_value} gp)")
+            print(f"  - None (Expected {total_value} gp)")
 
-    print("\nLevels:")
-    for lvl, amount in levels.items():
-        print(f"    Level {lvl}: {amount}")
+    if detailed:
+        print("\nLevels:")
+        for lvl, amount in levels.items():
+            print(f"  - Level {lvl}: {amount}")
 
-    print("\nCategories:")
-    for cat, amount in categories.items():
-        if cat:
-            print(f"    {cat.capitalize()}: {amount}")
-        else:
-            print(f"    None: {amount}")
+        print("\nCategories:")
+        for cat, amount in categories.items():
+            print(f"  - {cat.capitalize()}: {amount}")
 
-    print("\nRarities:")
-    for rar, amount in rarities.items():
-        print(f"    {rar.capitalize()}: {amount}")
+        print("\nSubcategories:")
+        for subcat, amount in subcategories.items():
+            print(f"  - {subcat.capitalize()}: {amount}")
 
+        print("\nRarities:")
+        for rar, amount in rarities.items():
+            print(f"  - {rar.capitalize()}: {amount}")
+
+    print()
 
 def find_single_item(item_name: str):
     """Fetches and prints information on a single item instead of a table."""
@@ -581,13 +614,17 @@ def find_single_item(item_name: str):
         print(f"Value: {item.price.sp}sp")
     elif item.price.cp != 0:
         print(f"Value: {item.price.cp}cp")
+    else:
+        print("Value: Undefined")
 
     print(
         textwrap.dedent(
             f"""\
         Level: {item.level}
         Category: {item.category.capitalize()}
-        Rarity: {item.rarity.capitalize()}\
+        Subcategory: {item.subcategory.capitalize()}
+        Rarity: {item.rarity.capitalize()}
+        Bulk: {item.bulk}\
         """
         )
     )
@@ -604,6 +641,12 @@ def entry_point():
         default="",
         help="the name of the text file containing the loot",
     )
+    parser.add_argument(
+        "-i",
+        "--item",
+        type=str,
+        help="run the script with only the specified item and exit",
+    )
     parser.add_argument(
         "-l",
         "--level",
@@ -617,6 +660,12 @@ def entry_point():
         default=0,
         help="a flat amount of gp to add to the total",
     )
+    parser.add_argument(
+        "-d",
+        "--detailed",
+        action="store_true",
+        help="show more information about the items than usual"
+    )
     parser.add_argument(
         "-f",
         "--format",
@@ -629,12 +678,6 @@ def entry_point():
         action="store_true",
         help="prevent conversion of coins into gp",
     )
-    parser.add_argument(
-        "-i",
-        "--item",
-        type=str,
-        help="run the script with only the specified item and exit",
-    )
     args = parser.parse_args()
 
     if args.format:
@@ -699,7 +742,7 @@ def entry_point():
         sys.exit(0)
 
     if os.path.isfile(args.input) and args.input.endswith(".txt"):
-        console_entry_point(args.input, args.level, args.currency, args.no_conversion)
+        console_entry_point(args.input, args.level, args.currency, args.detailed, args.no_conversion)
         sys.exit(0)
     else:
         print("Please input a valid text file or use the -i option")
